searchData={"items":[{"type":"module","title":"Sqlcommenter","doc":"Sqlcommenter is a library for adding sqlcommener comments to your ecto queries","ref":"Sqlcommenter.html"},{"type":"module","title":"Usage - Sqlcommenter","doc":"Install the library.\n  If your app is managing the migrations for your ecto repo you will need to follow these steps:\n  Duplicate the repo config in your to include this repo. It should be identical as the\n  exising Repo.  Duplicate your existing MyApp.Repo module to MyApp.MigrationsRepo.  Add a\n  config option to point to your exisiting migrations folder in MigrationsRepo in existing\n  Repo change use to use Sqlcommenter.Repo.  add any static sqlcommenter options that will\n  be included in all calls to the Repo config.\n\n At then end you will end up with 2 Repo modules just like this:\n\n```\ndefmodule Repo do\n  use Sqlcommenter.Repo,\n    otp_app: :my_app,\n    adapter: Ecto.Adapters.Postgres,\n    sqlcommenter: [app: \"test_app\", owner: \"team_c\"]\nend\n\ndefmodule MigrationRepo do\n  use Ecto.Repo,\n    otp_app: :my_app,\n    adapter: Ecto.Adapters.Postgres,\n    priv: \"priv/repo\"\nend\n``\n\nThe Sqlcommenter.Repo uses macros under the hood to get additional data from the caller so\nit needs to be required everywhere where it is used\n\n```\nrequire MyApp.Repo\nalias MyApp.Repo\n```\n\nYou can then use the Repo as normal.  The Sqlcommenter.Repo will add the sqlcommenter comment\nto the query.\n\n\n\n```\ndefmodule W do\n  require Test.Repo\n\n  def get do\n    Test.Repo.all(Weather)\n  end\nend\n\nW.get()\n```\nwill return a log line like this:\n```\n2024-10-26 09:21:27.368\nBST,\"postgres\",\"postgres\",89302,\"127.0.0.1:56568\",671ca5a8.15cd6,1,\"SELECT\",2024-10-26\n09:17:44 BST,9/37,0,LOG,00000,\"execute  : SELECT\nw0.\"\"id\"\", v1.\"\"name\"\" FROM \"\"weather\"\" AS w0 INNER JOIN (VALUES\n($1::bigint,$2::varchar),($3::bigint,$4::varchar)) AS v1 (\"\"id\"\",\"\"name\"\") ON v1.\"\"id\"\" =\nw0.\"\"id\"\"/*app='test_app',function='get%2F0',line='11',module='W',owner='team_c'*/\",\"parameters:\n$1 = '1', $2 = 'zabrze', $3 = '2', $4 = 'dudley'\",,,,,,,,\"\",\"client backend\",,0","ref":"Sqlcommenter.html#module-usage"},{"type":"module","title":"Sqlcommenter.Commenter","doc":"Documentation for `Sqlcommenter.Commenter`.","ref":"Sqlcommenter.Commenter.html"},{"type":"function","title":"Sqlcommenter.Commenter.append_to_io_query/2","doc":"Appends serialized data to query\n\niex> query = [\"SELECT\", [~s{p0.\"id\"}, \", \", ~s{p0.\"first_name\"}], \" FROM \", ~s{\"person\".\"person\"}, \" AS \", \"p0\"]\niex> Sqlcommenter.Commenter.append_to_io_query(query, %{controller: :person, function: :index})\n[\n  [\"SELECT\", [~s{p0.\"id\"}, \", \", ~s{p0.\"first_name\"}], \" FROM \", ~s{\"person\".\"person\"}, \" AS \", \"p0\"],\n  \" /*\",\n  [\n    [\"controller\", \"='\", \"person\", \"'\"],\n    \",\",\n    [\"function\", \"='\", \"index\", \"'\"]\n ],\n\"*/\"]","ref":"Sqlcommenter.Commenter.html#append_to_io_query/2"},{"type":"function","title":"Sqlcommenter.Commenter.append_to_query/2","doc":"Appends serialized data to query\n\niex> query = ~s{SELECT p0.\"id\", p0.\"first_name\" FROM \"person\".\"person\" AS p0}\niex> Sqlcommenter.Commenter.append_to_query(query, %{controller: :person, function: :index})\n~s{SELECT p0.\"id\", p0.\"first_name\" FROM \"person\".\"person\" AS p0 } <>\n\"/*controller='person',function='index'*/\"","ref":"Sqlcommenter.Commenter.html#append_to_query/2"},{"type":"function","title":"Sqlcommenter.Commenter.deserialize/1","doc":"extracts serialized data from query","ref":"Sqlcommenter.Commenter.html#deserialize/1"},{"type":"function","title":"Example - Sqlcommenter.Commenter.deserialize/1","doc":"iex> query = ~s{SELECT p0.\"id\", p0.\"first_name\" FROM \"person\".\"person\" AS p0 /*request_id='fa2af7b2-d8e1-4e8f-8820-3fd648b73187'*/}\niex> Sqlcommenter.Commenter.deserialize(query)\n%{\"request_id\" => \"fa2af7b2-d8e1-4e8f-8820-3fd648b73187\"}","ref":"Sqlcommenter.Commenter.html#deserialize/1-example"},{"type":"function","title":"Sqlcommenter.Commenter.sorted_to_iodata/1","doc":"The same as to_iodata but it assumes the keys are sorted already.","ref":"Sqlcommenter.Commenter.html#sorted_to_iodata/1"},{"type":"function","title":"Sqlcommenter.Commenter.to_iodata/1","doc":"Encodes enumerable to iodata\niex> Sqlcommenter.Commenter.to_iodata(controller: :person, function: :index)\n[\n    [\"controller\", \"='\", \"person\", \"'\"],\n    \",\",\n    [\"function\", \"='\", \"index\", \"'\"]\n]","ref":"Sqlcommenter.Commenter.html#to_iodata/1"},{"type":"function","title":"Sqlcommenter.Commenter.to_str/1","doc":"Encodes enumerable to string\niex> Sqlcommenter.Commenter.to_str(controller: :person, function: :index)\n\"controller='person',function='index'\"","ref":"Sqlcommenter.Commenter.html#to_str/1"},{"type":"module","title":"Sqlcommenter.Repo","doc":"","ref":"Sqlcommenter.Repo.html"},{"type":"function","title":"Sqlcommenter.Repo.all_running/0","doc":"","ref":"Sqlcommenter.Repo.html#all_running/0"},{"type":"type","title":"Sqlcommenter.Repo.t/0","doc":"","ref":"Sqlcommenter.Repo.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}